@@ -145,7 +145,8 @@ class Volume(cleanable.CinderCleanableObject, base.CinderObject,
 
     @classmethod
     def _get_expected_attrs(cls, context, *args, **kwargs):
-        expected_attrs = ['metadata', 'volume_type', 'volume_type.extra_specs']
+        expected_attrs = ['metadata', 'volume_type', 'volume_type.extra_specs',
+                          'volume_attachment']
         if context.is_admin:
             expected_attrs.append('admin_metadata')
 
@@ -514,7 +515,8 @@ class Volume(cleanable.CinderCleanableObject, base.CinderObject,
         # end of migration because we want to keep the original volume id
         # in the DB but now pointing to the migrated volume.
         skip = ({'id', 'provider_location', 'glance_metadata', 'use_quota',
-                 'volume_type'} | set(self.obj_extra_fields))
+                 'volume_type', 'volume_attachment'}
+                | set(self.obj_extra_fields))
         for key in set(dest_volume.fields.keys()) - skip:
             # Only swap attributes that are already set.  We do not want to
             # unexpectedly trigger a lazy-load.
