@@ -17,7 +17,7 @@ from oslo_versionedobjects import fixture
 from cinder import db
 from cinder import objects
 from cinder.objects import base
-from cinder import test
+from cinder.tests.unit import test
 
 
 # NOTE: The hashes in this list should only be changed if they come with a
@@ -45,9 +45,9 @@ object_data = {
     'RequestSpec': '1.5-2f6efbb86107ee70cc1bb07f4bdb4ec7',
     'Service': '1.6-e881b6b324151dd861e09cdfffcdaccd',
     'ServiceList': '1.1-15ecf022a68ddbb8c2a6739cfc9f8f5e',
-    'Snapshot': '1.5-ac1cdbd5b89588f6a8f44afdf6b8b201',
+    'Snapshot': '1.6-a2a1b62ae7e8d2794359ae59aff47ff6',
     'SnapshotList': '1.0-15ecf022a68ddbb8c2a6739cfc9f8f5e',
-    'Volume': '1.8-6cf615b72269cef48702a2a5c2940159',
+    'Volume': '1.9-4e25e166fa38bfcf039dcac1b19465b1',
     'VolumeList': '1.1-15ecf022a68ddbb8c2a6739cfc9f8f5e',
     'VolumeAttachment': '1.3-e6a3f7c5590d19f1e3ff6f819fbe6593',
     'VolumeAttachmentList': '1.1-15ecf022a68ddbb8c2a6739cfc9f8f5e',
@@ -80,6 +80,10 @@ class TestObjectVersions(test.TestCase):
                          "and we just have to change the hash in this module.")
 
     def test_versions_history(self):
+        # If we inserted a fake element in history, remove it so we don't fail
+        if base.OBJ_VERSIONS.get_current() == self.FAKE_OVO_HISTORY_VERSION:
+            fake_version = base.OBJ_VERSIONS.versions.pop(-1)
+            del base.OBJ_VERSIONS[fake_version]
         classes = base.CinderObjectRegistry.obj_classes()
         versions = base.OBJ_VERSIONS.get_current_versions()
         expected = {}
